.. _data:
************************************************
config (:mod:`MCEq.config`)
************************************************
.. currentmodule:: MCEq.config


These are all options MCEq accepts. 
Usually there is no need to change, except for advanced scenarios.
Check out the file for a better formatted description and some advanced settings not contained in the list below.

Reference/API
=============
.. automodapi:: MCEq.config
  :include-all-objects:
  :inherited-members:
